python-project
===============================================

This is Python project to demostrate python standard and pytest, tox, documentations, behave, etc.

This is sample Python package for PyPi packaging
